@@ -130,15 +130,14 @@ namespace Ogre {
         mRightBorderSize(0),
         mTopBorderSize(0),
         mBottomBorderSize(0),
+        mBorderUV{},
         mPixelLeftBorderSize(0),
         mPixelRightBorderSize(0),
         mPixelTopBorderSize(0),
         mPixelBottomBorderSize(0),
         mBorderMaterial(),
         mBorderRenderable(0)        
-    {   
-        mBorderUV->u1 = mBorderUV->u2 = mBorderUV->v1 = mBorderUV->v2 = 0;
-
+    {
         if (createParamDictionary("BorderPanelOverlayElement"))
         {
             addBaseParameters();
