@@ -24,6 +24,44 @@
 namespace Ogre
 {
 
+static void DrawConfigOption(RenderSystem* rs, const ConfigOption& opt)
+{
+    if(ImGui::BeginCombo(opt.name.c_str(), opt.currentValue.c_str()))
+    {
+        for(const auto& it : opt.possibleValues)
+        {
+            if(ImGui::Selectable(it.c_str(), it == opt.currentValue))
+                rs->setConfigOption(opt.name, it);
+        }
+        ImGui::EndCombo();
+    }
+}
+
+void DrawRenderingSettings(String& rsName)
+{
+    auto root = Root::getSingletonPtr();
+    OgreAssert(root, "Root must be created");
+
+    if(rsName.empty())
+        rsName = root->getRenderSystem()->getName();
+
+    if(ImGui::BeginCombo("Render System", rsName.c_str()))
+    {
+        for(const auto& it : root->getAvailableRenderers())
+        {
+            if(ImGui::Selectable(it->getName().c_str(), it->getName() == rsName))
+                rsName = it->getName();
+        }
+        ImGui::EndCombo();
+    }
+
+    ImGui::SeparatorText("Options");
+
+    auto rs = root->getRenderSystemByName(rsName);
+    for(const auto& it : rs->getConfigOptions())
+        DrawConfigOption(rs, it.second);
+}
+
 ImGuiOverlay::ImGuiOverlay() : Overlay("ImGuiOverlay")
 {
     ImGui::CreateContext();
@@ -49,7 +87,7 @@ void ImGuiOverlay::initialise()
 //-----------------------------------------------------------------------------------
 void ImGuiOverlay::_findVisibleObjects(Camera* cam, RenderQueue* queue, Viewport* vp)
 {
-    if (!mVisible)
+    if (!mInitialised)
         return;
 
     mRenderable._update();
@@ -62,14 +100,13 @@ void ImGuiOverlay::ImGUIRenderable::createMaterial()
     Pass* mPass = mMaterial->getTechnique(0)->getPass(0);
     mPass->setCullingMode(CULL_NONE);
     mPass->setVertexColourTracking(TVC_DIFFUSE);
-    mPass->setSceneBlending(SBT_TRANSPARENT_ALPHA);
-    mPass->setSeparateSceneBlendingOperation(SBO_ADD, SBO_ADD);
-    mPass->setSeparateSceneBlending(SBF_SOURCE_ALPHA, SBF_ONE_MINUS_SOURCE_ALPHA,
-                                    SBF_ONE_MINUS_SOURCE_ALPHA, SBF_ZERO);
+    mPass->setSceneBlendingOperation(SBO_ADD);
+    mPass->setSeparateSceneBlending(SBF_SOURCE_ALPHA, SBF_ONE_MINUS_SOURCE_ALPHA, SBF_ONE, SBF_ONE_MINUS_SOURCE_ALPHA);
 
     TextureUnitState* mTexUnit = mPass->createTextureUnitState();
     mTexUnit->setTexture(mFontTex);
     mTexUnit->setTextureFiltering(TFO_NONE);
+    mTexUnit->setTextureAddressingMode(TAM_CLAMP);
 
     mMaterial->load();
     mMaterial->setLightingEnabled(false);
@@ -80,11 +117,12 @@ void ImGuiOverlay::ImGUIRenderable::createMaterial()
 ImFont* ImGuiOverlay::addFont(const String& name, const String& group)
 {
     FontPtr font = FontManager::getSingleton().getByName(name, group);
-    OgreAssert(font, "font does not exist");
+    if (!font)
+        OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND,
+                    StringUtil::format("Font '%s' not found in group '%s'", name.c_str(), group.c_str()));
+
     OgreAssert(font->getType() == FT_TRUETYPE, "font must be of FT_TRUETYPE");
-    DataStreamPtr dataStreamPtr =
-        ResourceGroupManager::getSingleton().openResource(font->getSource(), font->getGroup());
-    MemoryDataStream ttfchunk(dataStreamPtr, false); // transfer ownership to imgui
+    MemoryDataStream ttfchunk(font->_getTTFData(), false); // transfer ownership to imgui
 
     // convert codepoint ranges for imgui
     CodePointRange cprange;
@@ -96,20 +134,45 @@ ImFont* ImGuiOverlay::addFont(const String& name, const String& group)
 
     ImGuiIO& io = ImGui::GetIO();
     const ImWchar* cprangePtr = io.Fonts->GetGlyphRangesDefault();
-    if (!cprange.empty())
-    {
-        cprange.push_back(0); // terminate
-        mCodePointRanges.push_back(cprange);
-        // ptr must persist until createFontTexture
-        cprangePtr = mCodePointRanges.back().data();
-    }
+    if (cprange.empty())
+        cprange = {32, 126}; // ogre default
+
+    cprange.push_back(0); // terminate
+    mCodePointRanges.push_back(cprange);
+    // ptr must persist until createFontTexture
+    cprangePtr = mCodePointRanges.back().data();
 
     float vpScale = OverlayManager::getSingleton().getPixelRatio();
 
     ImFontConfig cfg;
     strncpy(cfg.Name, name.c_str(), IM_ARRAYSIZE(cfg.Name) - 1);
-    return io.Fonts->AddFontFromMemoryTTF(ttfchunk.getPtr(), ttfchunk.size(), font->getTrueTypeSize() * vpScale, &cfg,
-                                          cprangePtr);
+    auto* ret = io.Fonts->AddFontFromMemoryTTF(ttfchunk.getPtr(), ttfchunk.size(), font->getTrueTypeSize() * vpScale,
+                                               &cfg, cprangePtr);
+
+    cfg.MergeMode = true;
+
+    for(const auto& mergeFont : font->getMergeFontList())
+    {
+        MemoryDataStream mergeTtfchunk(mergeFont->_getTTFData(), false); // transfer ownership to imgui
+
+        CodePointRange mergeCprange;
+        for (const auto& r : mergeFont->getCodePointRangeList())
+        {
+            mergeCprange.push_back(r.first);
+            mergeCprange.push_back(r.second);
+        }
+
+        OgreAssert(!mergeCprange.empty(), "merge font must have codepoint ranges");
+        mergeCprange.push_back(0); // terminate
+        mCodePointRanges.push_back(mergeCprange);
+        cprangePtr = mCodePointRanges.back().data();
+
+        cfg.MergeMode = true;
+        ret = io.Fonts->AddFontFromMemoryTTF(mergeTtfchunk.getPtr(), mergeTtfchunk.size(),
+                                             mergeFont->getTrueTypeSize() * vpScale, &cfg, cprangePtr);
+    }
+
+    return ret;
 }
 
 void ImGuiOverlay::ImGUIRenderable::createFontTexture()
@@ -160,6 +223,10 @@ void ImGuiOverlay::ImGUIRenderable::_update()
         mMaterial->load(); // Support for adding lights run time
     }
 
+    ImGui::Render();
+    ImDrawData* draw_data = ImGui::GetDrawData();
+    updateVertexData(draw_data);
+
     RenderSystem* rSys = Root::getSingleton().getRenderSystem();
 
     // Construct projection matrix, taking texel offset corrections in account (important for DirectX9)
@@ -186,18 +253,15 @@ bool ImGuiOverlay::ImGUIRenderable::preRender(SceneManager* sm, RenderSystem* rs
     // Instruct ImGui to Render() and process the resulting CmdList-s
     // Adopted from https://bitbucket.org/ChaosCreator/imgui-ogre2.1-binding
     // ... Commentary on OGRE forums: http://www.ogre3d.org/forums/viewtopic.php?f=5&t=89081#p531059
-    ImGui::Render();
-    ImDrawData* draw_data = ImGui::GetDrawData();
     int vpWidth = vp->getActualWidth();
     int vpHeight = vp->getActualHeight();
 
     TextureUnitState* tu = mMaterial->getBestTechnique()->getPass(0)->getTextureUnitState(0);
 
-    updateVertexData(draw_data);
-
     mRenderOp.indexData->indexStart = 0;
     mRenderOp.vertexData->vertexStart = 0;
 
+    ImDrawData* draw_data = ImGui::GetDrawData();
     for (int i = 0; i < draw_data->CmdListsCount; ++i)
     {
         const ImDrawList* draw_list = draw_data->CmdLists[i];
@@ -215,10 +279,9 @@ bool ImGuiOverlay::ImGUIRenderable::preRender(SceneManager* sm, RenderSystem* rs
             // Clamp bounds to viewport dimensions
             scissor = scissor.intersect(Rect(0, 0, vpWidth, vpHeight));
 
-            if (drawCmd->TextureId)
+            if (auto handle = drawCmd->GetTexID())
             {
-                auto handle = (ResourceHandle)drawCmd->TextureId;
-                auto tex = static_pointer_cast<Texture>(TextureManager::getSingleton().getByHandle(handle));
+                auto tex = static_pointer_cast<Texture>(TextureManager::getSingleton().getByHandle((ResourceHandle)handle));
                 if (tex)
                 {
                     rsys->_setTexture(0, true, tex);
@@ -233,7 +296,7 @@ bool ImGuiOverlay::ImGUIRenderable::preRender(SceneManager* sm, RenderSystem* rs
 
             rsys->_render(mRenderOp);
 
-            if (drawCmd->TextureId)
+            if (drawCmd->GetTexID())
             {
                 // reset to pass state
                 rsys->_setTexture(0, true, mFontTex);
@@ -296,6 +359,10 @@ void ImGuiOverlay::ImGUIRenderable::initialise(void)
 //-----------------------------------------------------------------------------------
 ImGuiOverlay::ImGUIRenderable::~ImGUIRenderable()
 {
+    if(mFontTex)
+        TextureManager::getSingleton().remove(mFontTex);
+    if(mMaterial)
+        MaterialManager::getSingleton().remove(mMaterial);
     OGRE_DELETE mRenderOp.vertexData;
     OGRE_DELETE mRenderOp.indexData;
 }
