@@ -39,11 +39,11 @@ namespace Ogre {
     //---------------------------------------------------------------------
     Overlay::Overlay(const String& name) :
         mName(name),
-        mRotate(0.0f), 
+        mRotate(0.0f),
         mScrollX(0.0f), mScrollY(0.0f),
         mScaleX(1.0f), mScaleY(1.0f),
         mLastViewportWidth(0), mLastViewportHeight(0),
-        mTransformOutOfDate(true), mTransformUpdated(true), 
+        mTransformOutOfDate(true), mTransformUpdated(true),
         mZOrder(100), mVisible(false), mInitialised(false)
 
     {
@@ -56,11 +56,10 @@ namespace Ogre {
         // remove children
 
         OGRE_DELETE mRootNode;
-        
-        for (OverlayContainerList::iterator i = m2DElements.begin(); 
-             i != m2DElements.end(); ++i)
+
+        for (auto *e : m2DElements)
         {
-            (*i)->_notifyParent(0, 0);
+            e->_notifyParent(0, 0);
         }
     }
     //---------------------------------------------------------------------
@@ -71,21 +70,18 @@ namespace Ogre {
     //---------------------------------------------------------------------
     void Overlay::assignZOrders()
     {
-        ushort zorder = static_cast<ushort>(mZOrder * 100.0f);
+        ushort zorder = mZOrder * ushort(100);
 
         // Notify attached 2D elements
-        OverlayContainerList::iterator i, iend;
-        iend = m2DElements.end();
-        for (i = m2DElements.begin(); i != iend; ++i)
+        for (auto *e : m2DElements)
         {
-            zorder = (*i)->_notifyZOrder(zorder);
+            zorder = e->_notifyZOrder(zorder);
         }
     }
     //---------------------------------------------------------------------
     void Overlay::setZOrder(ushort zorder)
     {
-        // Limit to 650 since this is multiplied by 100 to pad out for containers
-        assert (zorder <= 650 && "Overlay Z-order cannot be greater than 650!");
+        OgreAssert(zorder <= 655, "zorder is multiplied by 100 to pad out for containers");
 
         mZOrder = zorder;
 
@@ -94,7 +90,7 @@ namespace Ogre {
     //---------------------------------------------------------------------
     ushort Overlay::getZOrder(void) const
     {
-        return (ushort)mZOrder;
+        return mZOrder;
     }
     //---------------------------------------------------------------------
     bool Overlay::isVisible(void) const
@@ -123,11 +119,9 @@ namespace Ogre {
     //---------------------------------------------------------------------
     void Overlay::initialise(void)
     {
-        OverlayContainerList::iterator i, iend;
-        iend = m2DElements.end();
-        for (i = m2DElements.begin(); i != iend; ++i)
+        for (auto *e : m2DElements)
         {
-            (*i)->initialise();
+            e->initialise();
         }
         mInitialised = true;
     }
@@ -189,16 +183,10 @@ namespace Ogre {
       //---------------------------------------------------------------------
     OverlayContainer* Overlay::getChild(const String& name)
     {
-
-        OverlayContainerList::iterator i, iend;
-        iend = m2DElements.end();
-        for (i = m2DElements.begin(); i != iend; ++i)
+        for (auto *e : m2DElements)
         {
-            if ((*i)->getName() == name)
-            {
-                return *i;
-
-            }
+            if (e->getName() == name)
+                return e;
         }
         return NULL;
     }
@@ -269,10 +257,9 @@ namespace Ogre {
 
             if(tmpViewportDimensionsChanged)
             {
-                iend = m2DElements.end();
-                for (i = m2DElements.begin(); i != iend; ++i)
+                for (auto *e : m2DElements)
                 {
-                    (*i)->_notifyViewport();
+                    e->_notifyViewport();
                 }
             }
 
@@ -282,10 +269,9 @@ namespace Ogre {
                 Matrix4 xform;
                 _getWorldTransforms(&xform);
 
-                iend = m2DElements.end();
-                for (i = m2DElements.begin(); i != iend; ++i)
+                for (auto *e : m2DElements)
                 {
-                    (*i)->_notifyWorldTransforms(xform);
+                    e->_notifyWorldTransforms(xform);
                 }
 
                 mTransformUpdated = false;
@@ -305,12 +291,10 @@ namespace Ogre {
             queue->setDefaultQueueGroup(oldgrp);
             queue->setDefaultRenderablePriority(oldPriority);
             // Add 2D elements
-            iend = m2DElements.end();
-            for (i = m2DElements.begin(); i != iend; ++i)
+            for (auto *e : m2DElements)
             {
-                (*i)->_update();
-
-                (*i)->_updateRenderQueue(queue);
+                e->_update();
+                e->_updateRenderQueue(queue);
             }
         }
     }
@@ -342,14 +326,12 @@ namespace Ogre {
     {
         OverlayElement* ret = NULL;
         int currZ = -1;
-        OverlayContainerList::iterator i, iend;
-        iend = m2DElements.end();
-        for (i = m2DElements.begin(); i != iend; ++i)
+        for (auto *e : m2DElements)
         {
-            int z = (*i)->getZOrder();
+            int z = e->getZOrder();
             if (z > currZ)
             {
-                OverlayElement* elementFound = (*i)->findElementAt(x,y);
+                OverlayElement* elementFound = e->findElementAt(x,y);
                 if(elementFound)
                 {
                     currZ = elementFound->getZOrder();
@@ -359,6 +341,5 @@ namespace Ogre {
         }
         return ret;
     }
-
 }
 
