@@ -42,6 +42,8 @@ CGProgramWriter::CGProgramWriter()
     {
         mGpuConstTypeMap[GCT_SAMPLER2DARRAY] = "Sampler2DArray";
         mGpuConstTypeMap[GCT_SAMPLER2DSHADOW] = "Sampler2DShadow";
+        mGpuConstTypeMap[GCT_SAMPLER2DARRAYSHADOW] = "Sampler2DArrayShadow";
+        mGpuConstTypeMap[GCT_SAMPLERCUBESHADOW] = "SamplerCubeShadow";
     }
 }
 
@@ -81,6 +83,7 @@ void CGProgramWriter::initializeStringMaps()
     mGpuConstTypeMap[GCT_UINT4] = "uint4";
 
     mParamSemanticMap[Parameter::SPS_FRONT_FACING] = "VFACE";
+    mParamSemanticMap[Parameter::SPS_LAYER] = "SV_RenderTargetArrayIndex";
 }
 
 //-----------------------------------------------------------------------
@@ -98,10 +101,10 @@ void CGProgramWriter::writeSourceCode(std::ostream& os, Program* program)
     writeUniformParametersTitle(os, program);
     os << std::endl;
 
-    for (const auto& param : program->getParameters())
+    for (const auto& p : program->getParameters())
     {
-        param->isSampler() ? writeSamplerParameter(os, param) : writeParameter(os, param);
-        os << ";" << std::endl;             
+        p->isSampler() ? writeSamplerParameter(os, p) : writeParameter(os, p);
+        os << ";" << std::endl;
     }
     os << std::endl;
 
@@ -114,23 +117,17 @@ void CGProgramWriter::writeSourceCode(std::ostream& os, Program* program)
     os << "{" << std::endl;
 
     // Write local parameters.
-    const ShaderParameterList& localParams = curFunction->getLocalParameters();
-    ShaderParameterConstIterator itParam;
-
-    for (itParam=localParams.begin();  itParam != localParams.end(); ++itParam)
+    for (const auto& p : curFunction->getLocalParameters())
     {
         os << "\t";
-        writeParameter(os, *itParam);
+        writeParameter(os, p);
         os << ";" << std::endl;
     }
 
-    const FunctionAtomInstanceList& atomInstances = curFunction->getAtomInstances();
-    FunctionAtomInstanceConstIterator itAtom;
-
-    for (itAtom=atomInstances.begin(); itAtom != atomInstances.end(); ++itAtom)
+    for (const auto& a : curFunction->getAtomInstances())
     {
-        redirectGlobalWrites(os, *itAtom, curFunction->getInputParameters(), program->getParameters());
-        writeAtomInstance(os, *itAtom);
+        redirectGlobalWrites(os, a, curFunction->getInputParameters(), program->getParameters());
+        writeAtomInstance(os, a);
     }
 
 
@@ -138,28 +135,6 @@ void CGProgramWriter::writeSourceCode(std::ostream& os, Program* program)
     os << std::endl;
 }
 
-
-//-----------------------------------------------------------------------
-void CGProgramWriter::writeProgramDependencies(std::ostream& os, Program* program)
-{
-    os << "//-----------------------------------------------------------------------------" << std::endl;
-    os << "//                         PROGRAM DEPENDENCIES" << std::endl;
-    os << "//-----------------------------------------------------------------------------" << std::endl;
-
-    os << "#include <OgreUnifiedShader.h>" << std::endl;
-
-    const auto& rgm = ResourceGroupManager::getSingleton();
-
-    for (unsigned int i=0; i < program->getDependencyCount(); ++i)
-    {
-        String curDependency = program->getDependency(i) + ".cg";
-        if (!rgm.resourceExistsInAnyGroup(curDependency))
-            curDependency = program->getDependency(i) + ".glsl"; // fall back to glsl extension
-
-        os << "#include \"" << curDependency << '\"' << std::endl;
-    }
-}
-
 //-----------------------------------------------------------------------
 void CGProgramWriter::writeFunctionParameter(std::ostream& os, ParameterPtr parameter)
 {
@@ -171,28 +146,22 @@ void CGProgramWriter::writeFunctionParameter(std::ostream& os, ParameterPtr para
 //-----------------------------------------------------------------------
 void CGProgramWriter::writeFunctionDeclaration(std::ostream& os, Function* function)
 {
-    const ShaderParameterList& inParams  = function->getInputParameters();
-    const ShaderParameterList& outParams = function->getOutputParameters();
-
-
     os << "void main(\n";
 
-    ShaderParameterConstIterator it;
-
     // Write input parameters.
-    for (it=inParams.begin(); it != inParams.end(); ++it)
-    {                   
+    for (const auto& p : function->getInputParameters())
+    {
         os << "\t in ";
-        writeFunctionParameter(os, *it);
+        writeFunctionParameter(os, p);
         os << ",\n";
     }
 
 
     // Write output parameters.
-    for (it=outParams.begin(); it != outParams.end(); ++it)
+    for (const auto& p : function->getOutputParameters())
     {
         os << "\t out ";
-        writeFunctionParameter(os, *it);
+        writeFunctionParameter(os, p);
         os << ",\n";
     }
 
