@@ -5,6 +5,7 @@
 #ifndef _ShaderCookTorranceLighting_
 #define _ShaderCookTorranceLighting_
 
+#include "OgreScriptCompiler.h"
 #include "OgreShaderPrerequisites.h"
 #ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
 #include "OgreShaderExPerPixelLighting.h"
@@ -50,6 +51,7 @@ private:
     String mMetalRoughnessMapName;
     int mLightCount;
     uint8 mMRMapSamplerIndex;
+    int8 mLtcLUT1SamplerIndex;
 };
 
 class CookTorranceLightingFactory : public SubRenderStateFactory
@@ -57,8 +59,7 @@ class CookTorranceLightingFactory : public SubRenderStateFactory
 public:
     const String& getType() const override;
 
-    SubRenderState* createInstance(ScriptCompiler* compiler, PropertyAbstractNode* prop, Pass* pass,
-                                   SGScriptTranslator* translator) override;
+    SubRenderState* createInstance(const ScriptProperty& prop, Pass* pass, SGScriptTranslator* translator) override;
     void writeInstance(MaterialSerializer* ser, SubRenderState* subRenderState, Pass* srcPass, Pass* dstPass) override;
 
 protected:
