@@ -70,21 +70,12 @@ public:
     */
     bool preAddToRenderState(const RenderState* renderState, Pass* srcPass, Pass* dstPass) override;
 
-    /** 
-    Set the index of the input vertex shader texture coordinate set 
-    */
-    void setTexCoordIndex(unsigned int index) { mVSTexCoordSetIndex = index;}
-
-    /** 
-    Return the index of the input vertex shader texture coordinate set.
-    */
-    unsigned int getTexCoordIndex() const { return mVSTexCoordSetIndex; }
-
     enum NormalMapSpace
     {
         NMS_OBJECT = 1,
         NMS_TANGENT = 2,
-        NMS_PARALLAX = 6
+        NMS_PARALLAX = 6,
+        NMS_PARALLAX_OCCLUSION = 7
     };
 
     /** 
@@ -96,10 +87,7 @@ public:
     /** Return the normal map space. */
     NormalMapSpace getNormalMapSpace() const { return mNormalMapSpace; }
 
-    /** 
-    Return the normal map texture name.
-    */
-    const String& getNormalMapTextureName() const { return mNormalMapTextureName; }
+    int getNormalMapSamplerIndex() const { return mNormalMapSamplerIndex; }
 
     bool setParameter(const String& name, const String& value) override;
 
@@ -108,17 +96,15 @@ protected:
     bool createCpuSubPrograms(ProgramSet* programSet) override;
 
 // Attributes.
-protected:  
-    // The normal map texture name.
-    String mNormalMapTextureName;
+protected:
     // Normal map texture sampler index.
-    unsigned short mNormalMapSamplerIndex;
+    int mNormalMapSamplerIndex;
     // Vertex shader input texture coordinate set index.
     unsigned int mVSTexCoordSetIndex;
-    // The normal map sampler
-    SamplerPtr mNormalMapSampler;
     // The normal map space.
     NormalMapSpace mNormalMapSpace;
+    // Parallax mapping scale
+    float mParallaxHeightScale;
 };
 
 
@@ -138,12 +124,14 @@ public:
     /** 
     @see SubRenderStateFactory::createInstance.
     */
-    SubRenderState* createInstance(ScriptCompiler* compiler, PropertyAbstractNode* prop, Pass* pass, SGScriptTranslator* translator) override;
+    SubRenderState* createInstance(const ScriptProperty& prop, Pass* pass, SGScriptTranslator* translator) override;
+
+    SubRenderState* createInstance(const ScriptProperty& prop, TextureUnitState* texState, SGScriptTranslator* translator) override;
 
     /** 
     @see SubRenderStateFactory::writeInstance.
     */
-    void writeInstance(MaterialSerializer* ser, SubRenderState* subRenderState, Pass* srcPass, Pass* dstPass) override;
+    void writeInstance(MaterialSerializer* ser, SubRenderState* subRenderState, const TextureUnitState* srcTex, const TextureUnitState* dstTex) override;
 
     
 protected:
