@@ -49,6 +49,12 @@ bool ImageBasedLighting::preAddToRenderState(const RenderState* renderState, Pas
 {
     if (!srcPass->getLightingEnabled())
         return false;
+
+    // requires GLES3
+    if (ShaderGenerator::getSingleton().getTargetLanguage() == "glsles" &&
+        !GpuProgramManager::getSingleton().isSyntaxSupported("glsl300es"))
+        return false;
+
     // generate with ./cmgen --size=64 --ibl-dfg-multiscatter --ibl-dfg=dfgLUTmultiscatter.dds
     // see https://github.com/google/filament/blob/78554d231947bae965492eb5c47ad24a8d4a426e/filament/CMakeLists.txt#L510
     auto tus = dstPass->createTextureUnitState("dfgLUTmultiscatter.dds");
@@ -122,31 +128,30 @@ void ImageBasedLighting::updateGpuProgramsParams(Renderable* rend, const Pass* p
 const String& ImageBasedLightingFactory::getType() const { return SRS_IMAGE_BASED_LIGHTING; }
 
 //-----------------------------------------------------------------------
-SubRenderState* ImageBasedLightingFactory::createInstance(ScriptCompiler* compiler, PropertyAbstractNode* prop, Pass* pass,
-                                               SGScriptTranslator* translator)
+SubRenderState* ImageBasedLightingFactory::createInstance(const ScriptProperty& prop, Pass* pass,
+                                                          SGScriptTranslator* translator)
 {
-    if (prop->name != "image_based_lighting" || prop->values.size() < 2)
+    if (prop.name != "image_based_lighting" || prop.values.size() < 2)
         return NULL;
 
-    auto it = prop->values.begin();
-    if((*it++)->getString() != "texture")
+    if(prop.values[0] != "texture")
     {
-        compiler->addError(ScriptCompiler::CE_INVALIDPARAMETERS, prop->file, prop->line);
+        translator->emitError();
         return NULL;
     }
     auto ret = static_cast<ImageBasedLighting*>(createOrRetrieveInstance(translator));
-    ret->setParameter("texture", (*it++)->getString());
+    ret->setParameter("texture", prop.values[1]);
 
-    if (prop->values.size() < 4)
+    if (prop.values.size() < 4)
         return ret;
 
-    if((*it++)->getString() != "luminance")
+    if(prop.values[2] != "luminance")
     {
-        compiler->addError(ScriptCompiler::CE_INVALIDPARAMETERS, prop->file, prop->line);
+        translator->emitError();
         return NULL;
     }
 
-    ret->setParameter("luminance", (*it++)->getString());
+    ret->setParameter("luminance", prop.values[3]);
 
     return ret;
 }
