@@ -68,7 +68,11 @@ namespace Ogre {
             DEFAULT_PRIORITY = 100
         };
 
-        Renderable() : mPolygonModeOverrideable(true), mUseIdentityProjection(false), mUseIdentityView(false){}
+        Renderable()
+            : mMaterialLodIndex(0), mPolygonModeOverrideable(true), mUseIdentityProjection(false),
+              mUseIdentityView(false)
+        {
+        }
         /** Virtual destructor needed as class has virtual methods. */
         virtual ~Renderable() {}
         /** Retrieves a weak reference to the material this renderable object uses.
@@ -82,11 +86,13 @@ namespace Ogre {
             This is to allow Renderables to use a chosen Technique if they wish, otherwise
             they will use the best Technique available for the Material they are using.
         */
-        virtual Technique* getTechnique(void) const { return getMaterial()->getBestTechnique(0, this); }
+        virtual Technique* getTechnique(void) const { return getMaterial()->getBestTechnique(mMaterialLodIndex, this); }
         /** Gets the render operation required to send this object to the frame buffer.
         */
         virtual void getRenderOperation(RenderOperation& op) = 0;
 
+        uint16 _getMaterialLodIndex() const { return mMaterialLodIndex; }
+
         /** Called just prior to the Renderable being rendered. 
 
             OGRE is a queued renderer, so the actual render commands are executed 
@@ -123,25 +129,31 @@ namespace Ogre {
 
             If the object has any derived transforms, these are expected to be up to date as long as
             all the SceneNode structures have been updated before this is called.
-        @par
-            This method will populate transform with 1 matrix if it does not use vertex blending. If it
-            does use vertex blending it will fill the passed in pointer with an array of matrices,
-            the length being the value returned from getNumWorldTransforms.
+
         @note
             Internal Ogre never supports non-affine matrix for world transform matrix/matrices,
             the behavior is undefined if returns non-affine matrix here.
+
+            This method will populate transform with 1 matrix if it does not use GPU vertex blending. If it
+            does use GPU vertex blending it will fill the passed in pointer with an array of matrices,
+            the length being the value returned from @ref getNumWorldTransforms.
+
+        @note If @ref MeshManager::getBonesUseObjectSpace() is true, the first matrix must contain the world
+            transform of the object, and the rest of the matrices must contain the bone transforms in object space.
         */
         virtual void getWorldTransforms(Matrix4* xform) const = 0;
 
         /** Returns the number of world transform matrices this renderable requires.
 
-            When a renderable uses vertex blending, it uses multiple world matrices instead of a single
+            When a renderable uses GPU vertex blending, it uses multiple world matrices instead of a single
             one. Each vertex sent to the pipeline can reference one or more matrices in this list
             with given weights.
             If a renderable does not use vertex blending this method returns 1, which is the default for 
             simplicity.
+            @note If @ref MeshManager::getBonesUseObjectSpace() is true, this method must return
+            numBones + 1
         */
-        virtual unsigned short getNumWorldTransforms(void) const { return 1; }
+        virtual uint16 getNumWorldTransforms(void) const { return 1; }
 
         /** Sets whether or not to use an 'identity' projection.
 
@@ -229,7 +241,7 @@ namespace Ogre {
             two is performed by the ACT_CUSTOM entry, if that is used.
         @param value The value to associate.
         */
-        void setCustomParameter(size_t index, const Vector4& value);
+        void setCustomParameter(size_t index, const Vector4f& value);
 
         /** Removes a custom value which is associated with this Renderable at the given index.
         @param index Index of the parameter to remove.
@@ -247,7 +259,7 @@ namespace Ogre {
         @param index Index of the parameter to retrieve.
             @see setCustomParameter for full details.
         */
-        const Vector4& getCustomParameter(size_t index) const;
+        const Vector4f& getCustomParameter(size_t index) const;
 
         /** Update a custom GpuProgramParameters constant which is derived from 
             information only this Renderable knows.
@@ -341,9 +353,10 @@ namespace Ogre {
         };
 
     protected:
-        typedef std::map<size_t, Vector4> CustomParameterMap;
+        typedef std::map<size_t, Vector4f> CustomParameterMap;
         CustomParameterMap mCustomParameters;
         UserObjectBindings mUserObjectBindings;      /// User objects binding.
+        uint16 mMaterialLodIndex;
         bool mPolygonModeOverrideable;
         bool mUseIdentityProjection;
         bool mUseIdentityView;
