@@ -28,6 +28,8 @@ THE SOFTWARE.
 #include "OgreStableHeaders.h"
 
 #include "OgreRenderQueue.h"
+
+#include <memory>
 #include "OgreMaterial.h"
 #include "OgreRenderQueueSortingGrouping.h"
 #include "OgreSceneManagerEnumerator.h"
@@ -42,8 +44,8 @@ namespace Ogre {
         , mRenderableListener(0)
     {
         // Create the 'main' queue up-front since we'll always need that
-        mGroups[RENDER_QUEUE_MAIN].reset(new RenderQueueGroup(
-            mSplitPassesByLightingType, mSplitNoShadowPasses, mShadowCastersCannotBeReceivers));
+        mGroups[RENDER_QUEUE_MAIN] = std::make_unique<RenderQueueGroup>(
+            mSplitPassesByLightingType, mSplitNoShadowPasses, mShadowCastersCannotBeReceivers);
 
         // set default queue
         mDefaultQueueGroup = RENDER_QUEUE_MAIN;
@@ -57,12 +59,25 @@ namespace Ogre {
         // trigger the pending pass updates, otherwise we could leak
         Pass::processPendingPassUpdates();
     }
+
+    static bool onTransparentQueue(Technique* pTech)
+    {
+        // Transparent and depth/colour settings mean depth sorting is required?
+        // Note: colour write disabled with depth check/write enabled means
+        //       setup depth buffer for other passes use.
+        if (pTech->isTransparentSortingForced() ||
+            (pTech->isTransparent() &&
+             (!pTech->isDepthWriteEnabled() || !pTech->isDepthCheckEnabled() || pTech->hasColourWriteDisabled())))
+        {
+            return true;
+        }
+
+        return false;
+    }
+
     //-----------------------------------------------------------------------
     void RenderQueue::addRenderable(Renderable* pRend, uint8 groupID, ushort priority)
     {
-        // Find group
-        RenderQueueGroup* pGroup = getQueueGroup(groupID);
-
         Technique* pTech;
 
         // tell material it's been used
@@ -94,7 +109,12 @@ namespace Ogre {
             // tell material it's been used (incase changed)
             pTech->getParent()->touch();
         }
-        
+
+        if(groupID == mDefaultQueueGroup && onTransparentQueue(pTech))
+            groupID = RENDER_QUEUE_TRANSPARENTS;
+
+        // Find group
+        RenderQueueGroup* pGroup = getQueueGroup(groupID);
         pGroup->addRenderable(pRend, pTech, priority);
 
     }
@@ -161,8 +181,8 @@ namespace Ogre {
         if (!mGroups[groupID])
         {
             // Insert new
-            mGroups[groupID].reset(new RenderQueueGroup(mSplitPassesByLightingType, mSplitNoShadowPasses,
-                                                        mShadowCastersCannotBeReceivers));
+            mGroups[groupID] = std::make_unique<RenderQueueGroup>(mSplitPassesByLightingType, mSplitNoShadowPasses,
+                                                        mShadowCastersCannotBeReceivers);
         }
 
         return mGroups[groupID].get();
