@@ -26,6 +26,7 @@ THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 #include "OgreD3D9Mappings.h"
+#include "OgreHardwareVertexBuffer.h"
 #include "OgreString.h"
 #include "OgreStringConverter.h"
 #include "OgreLogManager.h"
@@ -42,28 +43,15 @@ namespace Ogre
         {
         case SO_FLAT:
             return D3DSHADE_FLAT;
+        case SO_PHONG:
+            // phong is not supported in D3D9
+            OGRE_FALLTHROUGH;
         case SO_GOURAUD:
             return D3DSHADE_GOURAUD;
-        case SO_PHONG:
-            return D3DSHADE_PHONG;
         }
         return 0;
     }
     //---------------------------------------------------------------------
-    D3DLIGHTTYPE D3D9Mappings::get(Ogre::Light::LightTypes lightType)
-    {
-        switch( lightType )
-        {
-        case Light::LT_POINT:
-            return D3DLIGHT_POINT;
-        case Light::LT_DIRECTIONAL:
-            return D3DLIGHT_DIRECTIONAL;
-        case Light::LT_SPOTLIGHT:
-            return D3DLIGHT_SPOT;
-        }
-        return D3DLIGHT_FORCE_DWORD;
-    }
-    //---------------------------------------------------------------------
     DWORD D3D9Mappings::get(TexCoordCalcMethod m, const D3DCAPS9& caps)
     {
         switch( m )
@@ -97,13 +85,13 @@ namespace Ogre
     {
         switch( tam )
         {
-        case TextureUnitState::TAM_WRAP:
+        case TAM_WRAP:
             return D3DTADDRESS_WRAP;
-        case TextureUnitState::TAM_MIRROR:
+        case TAM_MIRROR:
             return D3DTADDRESS_MIRROR;
-        case TextureUnitState::TAM_CLAMP:
+        case TAM_CLAMP:
             return D3DTADDRESS_CLAMP;
-        case TextureUnitState::TAM_BORDER:
+        case TAM_BORDER:
             if (devCaps.TextureAddressCaps & D3DPTADDRESSCAPS_BORDER)
                 return D3DTADDRESS_BORDER;
             else
@@ -543,6 +531,10 @@ namespace Ogre
         case VET_USHORT4_NORM:
             // valid only with vertex shaders >= 2.0
             return D3DDECLTYPE_USHORT4N;
+        case VET_HALF2:
+            return D3DDECLTYPE_FLOAT16_2;
+        case VET_HALF4:
+            return D3DDECLTYPE_FLOAT16_4;
         }
         // to keep compiler happy
         return D3DDECLTYPE_FLOAT3;
