@@ -38,10 +38,10 @@ Copyright (c) 2000-2014 Torus Knot Software Ltd
 namespace Ogre {
 
     GL3PlusFBORenderTexture::GL3PlusFBORenderTexture(
-        GL3PlusFBOManager *manager, const String &name,
+        const String &name,
         const GLSurfaceDesc &target, bool writeGamma, uint fsaa):
         GLRenderTexture(name, target, writeGamma, fsaa),
-        mFB(manager, fsaa)
+        mFB(fsaa)
     {
         // Bind target to surface 0 and initialise
         mFB.bindSurface(0, target);
@@ -85,12 +85,6 @@ namespace Ogre {
         return result;
     }
 
-    void GL3PlusFBORenderTexture::detachDepthBuffer()
-    {
-        mFB.detachDepthBuffer();
-        GLRenderTexture::detachDepthBuffer();
-    }
-
     void GL3PlusFBORenderTexture::_detachDepthBuffer()
     {
         mFB.detachDepthBuffer();
@@ -144,11 +138,6 @@ namespace Ogre {
         }
     }
 
-    GL3PlusStateCacheManager* GL3PlusFBOManager::getStateCacheManager()
-    {
-        return mRenderSystem->_getStateCacheManager();
-    }
-
     void GL3PlusFBOManager::_createTempFramebuffer(GLuint internalFormat, GLuint fmt, GLenum dataType, GLuint &fb, GLuint &tid)
     {
         OGRE_CHECK_GL_ERROR(glGenFramebuffers(1, &fb));
@@ -465,7 +454,7 @@ namespace Ogre {
     GL3PlusFBORenderTexture *GL3PlusFBOManager::createRenderTexture(const String &name,
                                                                     const GLSurfaceDesc &target, bool writeGamma, uint fsaa)
     {
-        GL3PlusFBORenderTexture *retval = new GL3PlusFBORenderTexture(this, name, target, writeGamma, fsaa);
+        GL3PlusFBORenderTexture *retval = new GL3PlusFBORenderTexture(name, target, writeGamma, fsaa);
         return retval;
     }
 
