@@ -170,14 +170,6 @@ namespace Ogre {
             std::vector<uint8> tmpdata(size);
             for (uint32 mip = 0; mip <= mNumMipmaps; mip++)
             {
-#if OGRE_DEBUG_MODE
-                LogManager::getSingleton().logMessage("GLES2Texture::create - Mip: " + StringConverter::toString(mip) +
-                                                      " Width: " + StringConverter::toString(width) +
-                                                      " Height: " + StringConverter::toString(height) +
-                                                      " Internal Format: " + StringUtil::format("%x", internalformat) +
-                                                      " Format: " + StringUtil::format("%x", format)
-                                                       );
-#endif
                 size = static_cast<GLsizei>(PixelUtil::getMemorySize(width, height, depth, mFormat));
                 
                 switch(mTextureType)
@@ -230,13 +222,6 @@ namespace Ogre {
 
         if(hasGLES30)
         {
-#if OGRE_DEBUG_MODE
-            LogManager::getSingleton().logMessage("GLES2Texture::create - Name: " + mName +
-                                                      " ID: " + StringConverter::toString(mTextureID) +
-                                                      " Width: " + StringConverter::toString(width) +
-                                                      " Height: " + StringConverter::toString(height) +
-                                                      " Internal Format: " + StringUtil::format("%x", internalformat));
-#endif
             switch(mTextureType)
             {
                 case TEX_TYPE_1D:
@@ -259,17 +244,6 @@ namespace Ogre {
         // Run through this process to pregenerate mipmap pyramid
         for(uint32 mip = 0; mip <= mNumMipmaps; mip++)
         {
-#if OGRE_DEBUG_MODE
-            LogManager::getSingleton().logMessage("GLES2Texture::create - Mip: " + StringConverter::toString(mip) +
-                                                  " Name: " + mName +
-                                                  " ID: " + StringConverter::toString(mTextureID) +
-                                                  " Width: " + StringConverter::toString(width) +
-                                                  " Height: " + StringConverter::toString(height) +
-                                                  " Internal Format: " + StringUtil::format("%x", internalformat) +
-                                                  " Format: " + StringUtil::format("%x", format) +
-                                                  " Datatype: " + StringUtil::format("%x", datatype)
-                                                  );
-#endif
             // Normal formats
             switch(mTextureType)
             {
@@ -323,7 +297,7 @@ namespace Ogre {
     {
         _createGLTexResource();
         
-        _createSurfaceList();
+        createSurfaceList();
 
         // Get final internal format
         mFormat = getBuffer(0,0)->getFormat();
@@ -344,7 +318,7 @@ namespace Ogre {
     {
         if (!isManuallyLoaded())
         {
-            freeInternalResources();
+            unloadImpl();
         }
         else
         {
@@ -380,30 +354,9 @@ namespace Ogre {
     }
 #endif
 
-    void GLES2Texture::_createSurfaceList()
+    HardwarePixelBufferPtr GLES2Texture::createSurface(uint32 face, uint32 mip, uint32 width, uint32 height,
+                                                       uint32 depth)
     {
-        mSurfaceList.clear();
-
-        uint32 depth = mDepth;
-
-        // For all faces and mipmaps, store surfaces as HardwarePixelBufferSharedPtr
-        for (size_t face = 0; face < getNumFaces(); face++)
-        {
-            uint32 width = mWidth;
-            uint32 height = mHeight;
-
-            for (uint32 mip = 0; mip <= getNumMipmaps(); mip++)
-            {
-                auto buf = std::make_shared<GLES2TextureBuffer>(this, int(face), mip, width, height, depth);
-                mSurfaceList.push_back(buf);
-
-                if (width > 1)
-                    width = width / 2;
-                if (height > 1)
-                    height = height / 2;
-                if (depth > 1 && mTextureType != TEX_TYPE_2D_ARRAY)
-                    depth = depth / 2;
-            }
-        }
+        return std::make_shared<GLES2TextureBuffer>(this, face, mip, width, height, depth);
     }
 }
