@@ -28,6 +28,8 @@ THE SOFTWARE.
 
 #include "OgreVulkanTextureGpu.h"
 
+#include <memory>
+
 #include "OgreException.h"
 #include "OgreVector.h"
 #include "OgreVulkanMappings.h"
@@ -44,7 +46,7 @@ namespace Ogre
 {
     VulkanHardwarePixelBuffer::VulkanHardwarePixelBuffer(VulkanTextureGpu* tex, uint32 width, uint32 height, uint32 depth,
                                                         uint8 face, uint32 mip)
-        : HardwarePixelBuffer(width, height, depth, tex->getFormat(), tex->getUsage(), false, false), mParent(tex),
+        : HardwarePixelBuffer(width, height, depth, tex->getFormat(), tex->getUsage(), false), mParent(tex),
         mFace(face), mLevel(mip)
     {
         if(mParent->getUsage() & TU_RENDERTARGET)
@@ -53,10 +55,9 @@ namespace Ogre
             mSliceTRT.reserve(mDepth);
             for(size_t zoffset=0; zoffset<mDepth; ++zoffset)
             {
-                String name;
-                name = "rtt/"+StringConverter::toString((size_t)this) + "/" + mParent->getName();
+                String name = getNameForRenderTexture(mParent->getName(), zoffset + face);
 
-                RenderTexture *trt = new VulkanRenderTexture(name, this, zoffset, mParent, mFace);
+                RenderTexture *trt = new VulkanRenderTexture(name, this, zoffset + face, mParent);
                 mSliceTRT.push_back(trt);
                 Root::getSingleton().getRenderSystem()->attachRenderTarget(*trt);
             }
@@ -65,7 +66,7 @@ namespace Ogre
 
     PixelBox VulkanHardwarePixelBuffer::lockImpl(const Box &lockBox,  LockOptions options)
     {
-        PixelBox ret(lockBox, mParent->getFormat());
+        PixelBox ret(lockBox.getWidth(), lockBox.getHeight(), lockBox.getDepth(), mParent->getFormat());
 
         auto textureManager = static_cast<VulkanTextureGpuManager*>(mParent->getCreator());
         VulkanDevice* device = textureManager->getDevice();
@@ -74,7 +75,7 @@ namespace Ogre
         if(options != HBL_DISCARD && options != HBL_WRITE_ONLY)
             target |= VK_BUFFER_USAGE_TRANSFER_DST_BIT;
 
-        mStagingBuffer.reset(new VulkanHardwareBuffer(target, ret.getConsecutiveSize(), HBU_CPU_ONLY, false, device));
+        mStagingBuffer = std::make_unique<VulkanHardwareBuffer>(target, ret.getConsecutiveSize(), HBU_CPU_ONLY, false, device);
 
         if (options != HBL_DISCARD && options != HBL_WRITE_ONLY)
         {
@@ -104,7 +105,8 @@ namespace Ogre
             device->mGraphicsQueue.commitAndNextCommandBuffer();
         }
 
-        return PixelBox(lockBox, mParent->getFormat(), mStagingBuffer->lock(options));
+        ret.data = (uchar*)mStagingBuffer->lock(options);
+        return ret;
     }
 
     void VulkanHardwarePixelBuffer::unlockImpl()
@@ -128,16 +130,16 @@ namespace Ogre
             region.imageSubresource.baseArrayLayer = mFace;
             region.imageSubresource.layerCount = 1;
 
-            region.imageOffset.x = mCurrentLock.left;
-            region.imageOffset.y = mCurrentLock.top;
-            region.imageOffset.z = mCurrentLock.front;
-            region.imageExtent.width = mCurrentLock.getWidth();
-            region.imageExtent.height = mCurrentLock.getHeight();
-            region.imageExtent.depth = mCurrentLock.getDepth();
+            region.imageOffset.x = mLockedBox.left;
+            region.imageOffset.y = mLockedBox.top;
+            region.imageOffset.z = mLockedBox.front;
+            region.imageExtent.width = mLockedBox.getWidth();
+            region.imageExtent.height = mLockedBox.getHeight();
+            region.imageExtent.depth = mLockedBox.getDepth();
 
             if (mParent->getTextureType() == TEX_TYPE_2D_ARRAY)
             {
-                region.imageSubresource.baseArrayLayer = mCurrentLock.front;
+                region.imageSubresource.baseArrayLayer = mLockedBox.front;
                 region.imageOffset.z = 0;
             }
 
@@ -154,21 +156,8 @@ namespace Ogre
     void VulkanHardwarePixelBuffer::blitFromMemory(const PixelBox& src, const Box& dstBox)
     {
         OgreAssert(src.getSize() == dstBox.getSize(), "scaling currently not supported");
-        // convert to image native format if necessary
-        if(src.format != mFormat)
-        {
-            std::vector<uint8> buffer;
-            buffer.resize(PixelUtil::getMemorySize(src.getWidth(), src.getHeight(), src.getDepth(), mFormat));
-            PixelBox converted = PixelBox(src.getWidth(), src.getHeight(), src.getDepth(), mFormat, buffer.data());
-            PixelUtil::bulkPixelConversion(src, converted);
-            blitFromMemory(converted, dstBox); // recursive call
-            return;
-        }
-
-        auto ptr = lock(dstBox, HBL_WRITE_ONLY).data;
-
-        memcpy(ptr, src.data, src.getConsecutiveSize());
-
+        lock(dstBox, HBL_WRITE_ONLY);
+        PixelUtil::bulkPixelConversion(src, mCurrentLock);
         unlock();
     }
     void VulkanHardwarePixelBuffer::blitToMemory(const Box& srcBox, const PixelBox& dst)
@@ -196,6 +185,11 @@ namespace Ogre
     //-----------------------------------------------------------------------------------
     VulkanTextureGpu::~VulkanTextureGpu() { unload(); }
     //-----------------------------------------------------------------------------------
+    HardwarePixelBufferPtr VulkanTextureGpu::createSurface(uint32 face, uint32 mipmap, uint32 width, uint32 height,
+                                                           uint32 depth)
+    {
+        return std::make_shared<VulkanHardwarePixelBuffer>(this, width, height, depth, face, mipmap);
+    }
     void VulkanTextureGpu::createInternalResourcesImpl( void )
     {
         if( mFormat == PF_UNKNOWN )
@@ -278,24 +272,7 @@ namespace Ogre
         mNextLayout = VK_IMAGE_LAYOUT_SHADER_READ_ONLY_OPTIMAL;
 
         // create
-        uint32 depth = mDepth;
-        for (uint8 face = 0; face < getNumFaces(); face++)
-        {
-            uint32 width = mWidth;
-            uint32 height = mHeight;
-
-            for (uint32 mip = 0; mip <= getNumMipmaps(); mip++)
-            {
-                auto buf = std::make_shared<VulkanHardwarePixelBuffer>(this, width, height, depth, face, mip);
-                mSurfaceList.push_back(buf);
-                if (width > 1)
-                    width = width / 2;
-                if (height > 1)
-                    height = height / 2;
-                if (depth > 1 && mTextureType != TEX_TYPE_2D_ARRAY)
-                    depth = depth / 2;
-            }
-        }
+        createSurfaceList();
 
         mDefaultDisplaySrv = _createView(0, 0, 0, getNumLayers());
 
@@ -615,6 +592,12 @@ namespace Ogre
         else
             imageViewCi.subresourceRange.layerCount = numSlices;
 
+        if(mUsage & TU_TARGET_ALL_LAYERS)
+        {
+            imageViewCi.subresourceRange.baseArrayLayer = 0;
+            imageViewCi.subresourceRange.layerCount = getNumLayers();
+        }
+
         VkImageViewUsageCreateInfo flagRestriction = {VK_STRUCTURE_TYPE_IMAGE_VIEW_USAGE_CREATE_INFO};
         if( textureManager->canRestrictImageViewUsage() && isUav() )
         {
@@ -725,9 +708,9 @@ namespace Ogre
         vmaDestroyImage(device->getAllocator(), mMsaaTextureName, mMsaaAllocation);
     }
 
-    VulkanRenderTexture::VulkanRenderTexture(const String& name, HardwarePixelBuffer* buffer, uint32 zoffset,
-                                             VulkanTextureGpu* target, uint32 face)
-        : RenderTexture(buffer, zoffset)
+    VulkanRenderTexture::VulkanRenderTexture(const String& name, HardwarePixelBuffer* buffer, uint32 slice,
+                                             VulkanTextureGpu* target)
+        : RenderTexture(buffer, slice)
     {
         mName = name;
 
@@ -740,7 +723,7 @@ namespace Ogre
 
         if(!depthTarget)
         {
-            mDepthTexture.reset(new VulkanTextureGpu(texMgr, mName+"/Depth", 0, "", true, 0));
+            mDepthTexture = std::make_unique<VulkanTextureGpu>(texMgr, mName+"/Depth", 0, "", true, nullptr);
             mDepthTexture->setWidth(target->getWidth());
             mDepthTexture->setHeight(target->getHeight());
             mDepthTexture->setFormat(PF_DEPTH32);
@@ -748,9 +731,9 @@ namespace Ogre
             mDepthTexture->setFSAA(1, "");
         }
 
-        mRenderPassDescriptor.reset(new VulkanRenderPassDescriptor(&device->mGraphicsQueue, device->mRenderSystem));
+        mRenderPassDescriptor = std::make_unique<VulkanRenderPassDescriptor>(&device->mGraphicsQueue, device->mRenderSystem);
         mRenderPassDescriptor->mColour[0] = depthTarget ? 0 : target;
-        mRenderPassDescriptor->mSlice = face;
+        mRenderPassDescriptor->mSlice = slice;
         mRenderPassDescriptor->mDepth = depthTarget ? target : mDepthTexture.get();
         mRenderPassDescriptor->mNumColourEntries = int(depthTarget == 0);
         mRenderPassDescriptor->entriesModified(true);
