@@ -56,11 +56,11 @@ class _OgreSampleClassExport Sample_Grass : public SdkSample
     /*=============================================================================
     // This class will be used to pulsate the light and billboard.
     =============================================================================*/
-    class LightPulse : public ControllerValue<Real>
+    class LightPulse : public ControllerValue<float>
  {
  public:
 
-     LightPulse(Light* light, Billboard* billboard, const ColourValue& maxColour, Real maxSize)
+     LightPulse(Light* light, Billboard* billboard, const ColourValue& maxColour, float maxSize)
      {
          mLight = light;
          mBillboard = billboard;
@@ -68,12 +68,12 @@ class _OgreSampleClassExport Sample_Grass : public SdkSample
          mMaxSize = maxSize;
      }
 
-     Real getValue () const override
+     float getValue () const override
      {
          return mIntensity;
      }
 
-     void setValue (Real value) override
+     void setValue (float value) override
      {
          mIntensity = value;
 
@@ -83,7 +83,7 @@ class _OgreSampleClassExport Sample_Grass : public SdkSample
          mBillboard->setColour(newColour);
 
          // calculate new billboard size and apply it
-         Real newSize = mMaxSize * mIntensity;
+         float newSize = mMaxSize * mIntensity;
          mBillboard->setDimensions(newSize, newSize);
      }
 
@@ -92,8 +92,8 @@ class _OgreSampleClassExport Sample_Grass : public SdkSample
      Light* mLight;
      Billboard* mBillboard;
      ColourValue mMaxColour;
-     Real mMaxSize;
-     Real mIntensity;
+     float mMaxSize;
+     float mIntensity;
  };
 
  void setupContent() override
@@ -142,9 +142,7 @@ class _OgreSampleClassExport Sample_Grass : public SdkSample
 
      // build tangent vectors for the ogre head mesh
      MeshPtr headMesh = MeshManager::getSingleton().load("ogrehead.mesh", ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
-     unsigned short src, dest;
-     if (!headMesh->suggestTangentVectorBuildParams(VES_TANGENT, src, dest))
-         headMesh->buildTangentVectors(VES_TANGENT, src, dest);
+     headMesh->buildTangentVectors();
 
      // put an ogre head in the middle of the field
      Entity* head = mSceneMgr->createEntity("Head", "ogrehead.mesh");
@@ -222,8 +220,8 @@ class _OgreSampleClassExport Sample_Grass : public SdkSample
      Billboard* bb = bbs->createBillboard(0, 0, 0, lightColour);
 
      // create a controller for the light intensity, using our LightPulsator class
-     ControllerFunctionRealPtr func(OGRE_NEW WaveformControllerFunction(Ogre::WFT_SINE, 0.5, 0.5, 0, 0.5));
-     ControllerValueRealPtr dest(OGRE_NEW LightPulse(light, bb, lightColour, 15));
+     auto func = WaveformControllerFunction::create(WFT_SINE, 0.5, 0.5, 0, 0.5);
+     auto dest = std::make_shared<LightPulse>(light, bb, lightColour, 15.0f);
      ControllerManager& cm = ControllerManager::getSingleton();
      mLightController = cm.createController(cm.getFrameTimeSource(), dest, func);
 
@@ -315,7 +313,7 @@ class _OgreSampleClassExport Sample_Grass : public SdkSample
 
  StaticGeometry* mField;
  AnimationState* mLightAnimState;
- ControllerReal* mLightController;
+ ControllerFloat* mLightController;
 };
 
 #endif
