@@ -33,10 +33,9 @@ THE SOFTWARE.
 #include "OgreArchiveManager.h"
 #include "MeshWithoutIndexDataTests.h"
 #include "OgreLodStrategyManager.h"
-#include "OgreLodConfig.h"
-
 
 #ifdef OGRE_BUILD_COMPONENT_MESHLODGENERATOR
+#include "OgreLodConfig.h"
 #include "OgreMeshLodGenerator.h"
 #endif
 
@@ -269,7 +268,7 @@ TEST_F(MeshWithoutIndexDataTests,CreateLineWithMaterial)
     mMeshMgr->remove(fileName, "General");
 }
 //--------------------------------------------------------------------------
-static void createMeshWithMaterial(String fileName)
+static void createMeshWithMaterial(const String& fileName)
 {
     String matFileNameSuffix = ".material";
     String matName1 = "red";
